@@ -23,20 +23,23 @@ class HookService(RetrieveMixin, UpdateMixin):
         return self._delete(f"{self.api_url}/{key}")
 
     def verify(self,
-               key: str = None,
-               secret_key: str = None):
-        params = dict()
-        params["access_token"] = self.token.access_token
-        print(secret_key)
-        headers = {
-            'Content-Type': 'application/json',
-            'X-Hook-Secret': secret_key
-        }
-        url = f'https://api.infusionsoft.com/crm/rest/v1/hooks/{key}/verify'
-        response = requests.request("POST", url, headers=headers, params=params)
-        print(response.json())
-        print('is ver')
-        return response
+               key: int = None):
+        return self._post(f"{self.api_url}/{key}/verify")
+    # def verify(self,
+    #            key: str = None,
+    #            secret_key: str = None):
+    #     params = dict()
+    #     params["access_token"] = self.token.access_token
+    #     print(secret_key)
+    #     headers = {
+    #         'Content-Type': 'application/json',
+    #         'X-Hook-Secret': secret_key
+    #     }
+    #     url = f'https://api.infusionsoft.com/crm/rest/v1/hooks/{key}/verify'
+    #     response = requests.request("POST", url, headers=headers, params=params)
+    #     print(response.json())
+    #     print('is ver')
+    #     return response
 
     def list_event_keys(self):
         return self._get(f"{self.api_url}/event_keys")
